pub struct OnchainOrderData {
pub sender: Address,
pub placement_error: Option<String>,
}Expand description
On-chain placement metadata for orders submitted directly on-chain (as opposed to the off-chain API).
Fields
sender: AddressThe address that created the on-chain order (may differ from owner for
EthFlow orders where the contract is the technical owner).
placement_error: Option<String>Non-None when the orderbook rejected the order due to a placement error.
Implementations
Sourceimpl OnchainOrderData
impl OnchainOrderData
Sourcepub const fn new(sender: Address) -> Self
pub const fn new(sender: Address) -> Self
Construct an OnchainOrderData record.
Sourcepub const fn has_placement_error(&self) -> bool
pub const fn has_placement_error(&self) -> bool
Returns true if a placement error was reported for this on-chain order.