pub struct BatchSwapStep {
pub pool_id: B256,
pub asset_in_index: u64,
pub asset_out_index: u64,
pub amount: U256,
pub user_data: Bytes,
}Expand description
An encoded Balancer batch swap step.
Corresponds to the TypeScript BatchSwapStep type.
Fields
pool_id: B256The Balancer pool ID.
asset_in_index: u64Index of the input token in the token array.
asset_out_index: u64Index of the output token in the token array.
amount: U256The amount to swap.
user_data: BytesAdditional pool user data.