EncodedTrade

Struct EncodedTrade 

pub struct EncodedTrade {
    pub sell_token_index: u64,
    pub buy_token_index: u64,
    pub receiver: Address,
    pub sell_amount: U256,
    pub buy_amount: U256,
    pub valid_to: u32,
    pub app_data: B256,
    pub fee_amount: U256,
    pub flags: u8,
    pub executed_amount: U256,
    pub signature: Bytes,
}
Encoded trade data as used in the settlement contract.

Corresponds to the TypeScript Trade type.

Fields

sell_token_index: u64

Index of the sell token in the settlement token array.

buy_token_index: u64

Index of the buy token in the settlement token array.

receiver: Address

Address that receives the bought tokens.

sell_amount: U256

Amount of sell token.

buy_amount: U256

Amount of buy token.

valid_to: u32

Order expiry as Unix timestamp.

app_data: B256

App-data hash.

fee_amount: U256

Fee amount.

flags: u8

Encoded trade flags.

executed_amount: U256

The executed trade amount.

signature: Bytes

Signature data.