BatchSwapStep

Struct BatchSwapStep 

pub struct BatchSwapStep {
    pub pool_id: B256,
    pub asset_in_index: u64,
    pub asset_out_index: u64,
    pub amount: U256,
    pub user_data: Bytes,
}
An encoded Balancer batch swap step.

Corresponds to the TypeScript BatchSwapStep type.

Fields

pool_id: B256

The Balancer pool ID.

asset_in_index: u64

Index of the input token in the token array.

asset_out_index: u64

Index of the output token in the token array.

amount: U256

The amount to swap.

user_data: Bytes

Additional pool user data.