pub struct EncodedTrade {
pub sell_token_index: u64,
pub buy_token_index: u64,
pub receiver: Address,
pub sell_amount: U256,
pub buy_amount: U256,
pub valid_to: u32,
pub app_data: B256,
pub fee_amount: U256,
pub flags: u8,
pub executed_amount: U256,
pub signature: Bytes,
}Expand description
Encoded trade data as used in the settlement contract.
Corresponds to the TypeScript Trade type.
Fields
sell_token_index: u64Index of the sell token in the settlement token array.
buy_token_index: u64Index of the buy token in the settlement token array.
receiver: AddressAddress that receives the bought tokens.
sell_amount: U256Amount of sell token.
buy_amount: U256Amount of buy token.
valid_to: u32Order expiry as Unix timestamp.
app_data: B256App-data hash.
fee_amount: U256Fee amount.
flags: u8Encoded trade flags.
executed_amount: U256The executed trade amount.
signature: BytesSignature data.